@@ -15,6 +15,13 @@ export const LAB_REQUEST_STATUSES = {
   ENTERED_IN_ERROR: 'entered-in-error',
 };
 
+export const INTERIM_LAB_REQUEST_STATUSES = [
+  LAB_REQUEST_STATUSES.RECEPTION_PENDING,
+  LAB_REQUEST_STATUSES.RESULTS_PENDING,
+  LAB_REQUEST_STATUSES.INTERIM_RESULTS,
+  LAB_REQUEST_STATUSES.TO_BE_VERIFIED,
+];
+
 export const LAB_REQUEST_STATUS_LABELS = {
   [LAB_REQUEST_STATUSES.RECEPTION_PENDING]: 'Reception pending',
   [LAB_REQUEST_STATUSES.RESULTS_PENDING]: 'Results pending',
@@ -31,47 +38,36 @@ export const LAB_REQUEST_STATUS_LABELS = {
 
 export const LAB_REQUEST_STATUS_CONFIG = {
   [LAB_REQUEST_STATUSES.RECEPTION_PENDING]: {
-    label: LAB_REQUEST_STATUS_LABELS[LAB_REQUEST_STATUSES.RECEPTION_PENDING],
     color: COLORS.pink,
   },
   [LAB_REQUEST_STATUSES.RESULTS_PENDING]: {
-    label: LAB_REQUEST_STATUS_LABELS[LAB_REQUEST_STATUSES.RESULTS_PENDING],
     color: COLORS.darkOrange,
   },
   [LAB_REQUEST_STATUSES.INTERIM_RESULTS]: {
-    label: LAB_REQUEST_STATUS_LABELS[LAB_REQUEST_STATUSES.INTERIM_RESULTS],
     color: '#006278',
   },
   [LAB_REQUEST_STATUSES.TO_BE_VERIFIED]: {
-    label: LAB_REQUEST_STATUS_LABELS[LAB_REQUEST_STATUSES.TO_BE_VERIFIED],
     color: COLORS.metallicYellow,
   },
   [LAB_REQUEST_STATUSES.VERIFIED]: {
-    label: LAB_REQUEST_STATUS_LABELS[LAB_REQUEST_STATUSES.VERIFIED],
     color: COLORS.blue,
   },
   [LAB_REQUEST_STATUSES.PUBLISHED]: {
-    label: LAB_REQUEST_STATUS_LABELS[LAB_REQUEST_STATUSES.PUBLISHED],
     color: COLORS.green,
   },
   [LAB_REQUEST_STATUSES.SAMPLE_NOT_COLLECTED]: {
-    label: LAB_REQUEST_STATUS_LABELS[LAB_REQUEST_STATUSES.SAMPLE_NOT_COLLECTED],
     color: COLORS.purple,
   },
   [LAB_REQUEST_STATUSES.CANCELLED]: {
-    label: LAB_REQUEST_STATUS_LABELS[LAB_REQUEST_STATUSES.CANCELLED],
     color: COLORS.grey,
   },
   [LAB_REQUEST_STATUSES.INVALIDATED]: {
-    label: LAB_REQUEST_STATUS_LABELS[LAB_REQUEST_STATUSES.INVALIDATED],
     color: COLORS.grey,
   },
   [LAB_REQUEST_STATUSES.DELETED]: {
-    label: LAB_REQUEST_STATUS_LABELS[LAB_REQUEST_STATUSES.DELETED],
     color: COLORS.grey,
   },
   [LAB_REQUEST_STATUSES.ENTERED_IN_ERROR]: {
-    label: LAB_REQUEST_STATUS_LABELS[LAB_REQUEST_STATUSES.ENTERED_IN_ERROR],
     color: COLORS.red,
     background: '#FFCEC7',
   },
@@ -81,8 +77,6 @@ export const LAB_REQUEST_STATUS_CONFIG = {
   },
 };
 
-export const LAB_TEST_STATUSES = LAB_REQUEST_STATUSES;
-
 export const LAB_TEST_RESULT_TYPES = {
   FREE_TEXT: 'FreeText',
   NUMBER: 'Number',
@@ -99,3 +93,19 @@ export const LAB_TEST_TYPE_VISIBILITY_STATUSES = {
   ...VISIBILITY_STATUSES,
   PANEL_ONLY: 'panelOnly',
 };
+
+// These are the status groupings for the versions of lab request table that filter by different statuses
+export const LAB_REQUEST_TABLE_STATUS_GROUPINGS: {
+  ACTIVE: string[];
+  COMPLETED: string[];
+} = {
+  ACTIVE: [
+    LAB_REQUEST_STATUSES.RECEPTION_PENDING,
+    LAB_REQUEST_STATUSES.RESULTS_PENDING,
+    LAB_REQUEST_STATUSES.INTERIM_RESULTS,
+    LAB_REQUEST_STATUSES.SAMPLE_NOT_COLLECTED,
+    LAB_REQUEST_STATUSES.TO_BE_VERIFIED,
+    LAB_REQUEST_STATUSES.VERIFIED,
+  ],
+  COMPLETED: [LAB_REQUEST_STATUSES.PUBLISHED, LAB_REQUEST_STATUSES.INVALIDATED],
+};
