@@ -1,3 +1,4 @@
+import { DataTypes } from 'sequelize';
 import { SYNC_DIRECTIONS } from '@tamanu/constants';
 import { Model } from './Model';
 import type { InitOptions, Models } from '../types/model';
@@ -6,11 +7,17 @@ export class LabTestPanelLabTestTypes extends Model {
   declare id: string;
   declare labTestPanelId?: string;
   declare labTestTypeId?: string;
+  declare order: number;
 
   static initModel({ primaryKey, ...options }: InitOptions) {
     super.init(
       {
         id: primaryKey,
+        order: {
+          type: DataTypes.INTEGER,
+          allowNull: false,
+          defaultValue: 0,
+        },
       },
       {
         ...options,
