@@ -1,5 +1,5 @@
 import asyncHandler from 'express-async-handler';
-import { Op, QueryTypes, literal } from 'sequelize';
+import { Op, literal } from 'sequelize';
 import { subject } from '@casl/ability';
 import { NotFoundError, InvalidParameterError, InvalidOperationError } from '@tamanu/errors';
 import { getCurrentDateTimeString } from '@tamanu/utils/dateTime';
@@ -27,6 +27,7 @@ import {
 } from '@tamanu/shared/utils/crudHelpers';
 import { add } from 'date-fns';
 import { z } from 'zod';
+import { deleteChartInstance, fetchAnswersWithHistory, fetchGraphData, fetchChartInstances } from '../../routeHandlers/charts';
 import { keyBy } from 'lodash';
 
 import { createEncounterSchema } from '@tamanu/shared/schemas/facility/requests/createEncounter.schema';
@@ -496,12 +497,12 @@ encounterRelations.get(
     const { models, params } = req;
     const encounterId = params.id;
     const noteTypeCounts = await models.Note.count({
-      group: ['noteType'],
+      group: ['noteTypeId'],
       where: { recordId: encounterId, recordType: 'Encounter' },
     });
     const noteTypeToCount = {};
     noteTypeCounts.forEach(n => {
-      noteTypeToCount[n.noteType] = n.count;
+      noteTypeToCount[n.noteTypeId] = n.count;
     });
     res.send({ data: noteTypeToCount });
   }),
@@ -633,212 +634,20 @@ encounterRelations.get(
 
 encounterRelations.delete('/:id/programResponses/:surveyResponseId', deleteSurveyResponse);
 
-// Used in charts and vitals to query responses based on the date of a response answer
-async function getAnswersWithHistory(req) {
-  const { db, params, query } = req;
-  const { id: encounterId, surveyId = null } = params;
-  const { order = 'DESC', instanceId = null } = query;
-
-  const isVitals = surveyId === null;
-  const dateDataElement = isVitals
-    ? VITALS_DATA_ELEMENT_IDS.dateRecorded
-    : CHARTING_DATA_ELEMENT_IDS.dateRecorded;
-
-  // The LIMIT and OFFSET occur in an unusual place in this query
-  // So we can't run it through the generic runPaginatedQuery function
-  const countResult = await db.query(
-    `
-      SELECT COUNT(1) AS count
-      FROM survey_response_answers
-      INNER JOIN survey_responses response
-      ON response.id = response_id
-      WHERE data_element_id = :dateDataElement
-      AND body IS NOT NULL
-      AND response.encounter_id = :encounterId
-      AND response.deleted_at IS NULL
-      AND CASE WHEN :surveyId IS NOT NULL THEN response.survey_id = :surveyId ELSE true END
-      AND CASE WHEN :instanceId IS NOT NULL THEN response.metadata->>'chartInstanceResponseId' = :instanceId ELSE true END
-    `,
-    {
-      replacements: {
-        encounterId,
-        dateDataElement,
-        surveyId,
-        instanceId,
-      },
-      type: QueryTypes.SELECT,
-    },
-  );
-  const { count } = countResult[0];
-  if (count === 0) {
-    return { data: [], count: 0 };
-  }
-
-  const { page = 0, rowsPerPage = 10 } = query;
-  const vitalsHistorySelect = `
-    SELECT
-      vl.answer_id,
-      ARRAY_AGG((
-        JSONB_BUILD_OBJECT(
-          'newValue', vl.new_value,
-          'reasonForChange', vl.reason_for_change,
-          'date', vl.date,
-          'userDisplayName', u.display_name
-        )
-      )) logs
-    FROM survey_response_answers sra
-      INNER JOIN survey_responses sr ON sr.id = sra.response_id
-      LEFT JOIN vital_logs vl ON vl.answer_id = sra.id
-      LEFT JOIN users u ON u.id = vl.recorded_by_id
-    WHERE sr.encounter_id = :encounterId
-      AND sr.deleted_at IS NULL
-    GROUP BY vl.answer_id
-  `;
-  const chartHistorySelect = `
-    SELECT
-      lc.record_id as answer_id,
-      ARRAY_AGG((
-        JSONB_BUILD_OBJECT(
-          'newValue', lc.record_data->>'body',
-          'reasonForChange', lc.reason,
-          'date', TO_CHAR(lc.logged_at, 'YYYY-MM-DD HH24:MI:SS'),
-          'userDisplayName', u.display_name
-        )
-      )) logs
-    FROM survey_response_answers sra
-      INNER JOIN survey_responses sr ON sr.id = sra.response_id
-      LEFT JOIN logs.changes lc ON lc.record_id = sra.id
-      LEFT JOIN users u ON u.id = lc.updated_by_user_id
-    WHERE sr.encounter_id = :encounterId
-      AND sr.deleted_at IS NULL
-      AND lc.table_name = 'survey_response_answers'
-      AND lc.migration_context IS NULL
-    GROUP BY lc.record_id
-  `;
-
-  const result = await db.query(
-    `
-      WITH
-      date AS (
-        SELECT response_id, body
-        FROM survey_response_answers
-        INNER JOIN survey_responses response
-        ON response.id = response_id
-        WHERE data_element_id = :dateDataElement
-        AND body IS NOT NULL
-        AND response.encounter_id = :encounterId
-        AND response.deleted_at IS NULL
-        AND CASE WHEN :surveyId IS NOT NULL THEN response.survey_id = :surveyId ELSE true END
-        AND CASE WHEN :instanceId IS NOT NULL THEN response.metadata->>'chartInstanceResponseId' = :instanceId ELSE true END
-        ORDER BY body ${order} LIMIT :limit OFFSET :offset
-      ),
-      history AS (
-        ${isVitals ? vitalsHistorySelect : chartHistorySelect}
-      )
-
-      SELECT
-        JSONB_BUILD_OBJECT(
-          'dataElementId', answer.data_element_id,
-          'records', JSONB_OBJECT_AGG(date.body, JSONB_BUILD_OBJECT('id', answer.id, 'body', answer.body, 'logs', history.logs))
-        ) result
-      FROM
-        survey_response_answers answer
-      INNER JOIN
-        date
-      ON date.response_id = answer.response_id
-      LEFT JOIN
-        history
-      ON history.answer_id = answer.id
-      GROUP BY answer.data_element_id
-    `,
-    {
-      replacements: {
-        encounterId,
-        limit: rowsPerPage,
-        offset: page * rowsPerPage,
-        dateDataElement,
-        surveyId,
-        instanceId,
-      },
-      type: QueryTypes.SELECT,
-    },
-  );
-
-  const data = result.map(r => r.result);
-  return { count, data };
-}
-
-async function getGraphData(req, dateDataElementId) {
-  const { models, params, query } = req;
-  const { id: encounterId, dataElementId } = params;
-  const { startDate, endDate } = query;
-  const { SurveyResponse, SurveyResponseAnswer } = models;
-
-  const dateAnswers = await SurveyResponseAnswer.findAll({
-    include: [
-      {
-        model: SurveyResponse,
-        required: true,
-        as: 'surveyResponse',
-        where: { encounterId },
-      },
-    ],
-    where: {
-      dataElementId: dateDataElementId,
-      body: { [Op.gte]: startDate, [Op.lte]: endDate },
-    },
-  });
-
-  const responseIds = dateAnswers.map(dateAnswer => dateAnswer.responseId);
-
-  const answers = await SurveyResponseAnswer.findAll({
-    where: {
-      responseId: responseIds,
-      dataElementId,
-      body: { [Op.and]: [{ [Op.ne]: '' }, { [Op.not]: null }] },
-    },
-  });
-
-  const data = answers
-    .map(answer => {
-      const { responseId } = answer;
-      const recordedDateAnswer = dateAnswers.find(
-        dateAnswer => dateAnswer.responseId === responseId,
-      );
-      const recordedDate = recordedDateAnswer.body;
-      return { ...answer.dataValues, recordedDate };
-    })
-    .sort((a, b) => {
-      return a.recordedDate > b.recordedDate ? 1 : -1;
-    });
-  // Survey ID will be the same for all answers because the
-  // data element ID is unique to the survey
-  return { data, surveyId: dateAnswers[0]?.surveyResponse.surveyId };
-}
-
 encounterRelations.get(
   '/:id/vitals',
-  asyncHandler(async (req, res) => {
-    req.checkPermission('list', 'Vitals');
-    const { count, data } = await getAnswersWithHistory(req);
-
-    res.send({
-      count: parseInt(count, 10),
-      data,
-    });
+  fetchAnswersWithHistory({
+    permissionAction: 'list',
+    permissionNoun: 'Vitals',
   }),
 );
 
 encounterRelations.get(
   '/:id/graphData/vitals/:dataElementId',
-  asyncHandler(async (req, res) => {
-    req.checkPermission('list', 'Vitals');
-    const { data } = await getGraphData(req, VITALS_DATA_ELEMENT_IDS.dateRecorded);
-
-    res.send({
-      count: data.length,
-      data,
-    });
+  fetchGraphData({
+    permissionAction: 'list',
+    permissionNoun: 'Vitals',
+    dateDataElementId: VITALS_DATA_ELEMENT_IDS.dateRecorded,
   }),
 );
 
@@ -877,28 +686,18 @@ encounterRelations.get(
 
 encounterRelations.get(
   '/:id/graphData/charts/:dataElementId',
-  asyncHandler(async (req, res) => {
-    const { data, surveyId } = await getGraphData(req, CHARTING_DATA_ELEMENT_IDS.dateRecorded);
-    req.checkPermission('read', subject('Charting', { id: surveyId }));
-
-    res.send({
-      count: data.length,
-      data,
-    });
+  fetchGraphData({
+    permissionAction: 'read',
+    permissionNoun: 'Charting',
+    dateDataElementId: CHARTING_DATA_ELEMENT_IDS.dateRecorded
   }),
 );
 
 encounterRelations.get(
   '/:id/charts/:surveyId',
-  asyncHandler(async (req, res) => {
-    const { surveyId } = req.params;
-    req.checkPermission('read', subject('Charting', { id: surveyId }));
-    const { count, data } = await getAnswersWithHistory(req);
-
-    res.send({
-      count: parseInt(count, 10),
-      data,
-    });
+  fetchAnswersWithHistory({
+    permissionAction: 'read',
+    permissionNoun: 'Charting',
   }),
 );
 
@@ -973,80 +772,14 @@ encounterRelations.get(
 
 encounterRelations.get(
   '/:id/charts/:chartSurveyId/chartInstances',
-  asyncHandler(async (req, res) => {
-    const { db, params } = req;
-    const { id: encounterId, chartSurveyId } = params;
-    req.checkPermission('list', subject('Charting', { id: chartSurveyId }));
-
-    const results = await db.query(
-      `
-        WITH chart_instances AS (
-          SELECT
-            sr.id AS "chartInstanceId",
-            sr.survey_id AS "chartSurveyId",
-            MAX(CASE WHEN sra.data_element_id = :complexChartInstanceNameElementId THEN sra.body END) AS "chartInstanceName",
-            MAX(CASE WHEN sra.data_element_id = :complexChartDateElementId THEN sra.body END) AS "chartDate",
-            MAX(CASE WHEN sra.data_element_id = :complexChartTypeElementId THEN sra.body END) AS "chartType",
-            MAX(CASE WHEN sra.data_element_id = :complexChartSubtypeElementId THEN sra.body END) AS "chartSubtype"
-          FROM
-            survey_responses sr
-          LEFT JOIN
-            survey_response_answers sra
-          ON
-            sr.id = sra.response_id
-          WHERE
-            sr.survey_id = :chartSurveyId AND
-            sr.encounter_id = :encounterId AND
-            sr.deleted_at IS NULL
-          GROUP BY
-            sr.id
-        )
-
-        SELECT
-          *
-        FROM chart_instances
-        ORDER BY "chartDate" DESC;
-      `,
-      {
-        replacements: {
-          encounterId,
-          chartSurveyId,
-          complexChartInstanceNameElementId: CHARTING_DATA_ELEMENT_IDS.complexChartInstanceName,
-          complexChartDateElementId: CHARTING_DATA_ELEMENT_IDS.complexChartDate,
-          complexChartTypeElementId: CHARTING_DATA_ELEMENT_IDS.complexChartType,
-          complexChartSubtypeElementId: CHARTING_DATA_ELEMENT_IDS.complexChartSubtype,
-        },
-        type: QueryTypes.SELECT,
-      },
-    );
-
-    res.send({
-      count: results.length,
-      data: results,
-    });
+  fetchChartInstances({
+    permissionAction: 'list',
   }),
 );
 
 encounterRelations.delete(
   '/:id/chartInstances/:chartInstanceResponseId',
-  asyncHandler(async (req, res) => {
-    const { db, params, models } = req;
-    const { chartInstanceResponseId } = params;
-
-    const surveyResponse = await models.SurveyResponse.findByPk(chartInstanceResponseId);
-    req.checkPermission('delete', subject('Charting', { id: surveyResponse?.surveyId }));
-
-    // all answers will also be soft deleted automatically
-    await db.transaction(async () => {
-      await models.SurveyResponse.destroy({ where: { id: chartInstanceResponseId } });
-
-      await models.SurveyResponse.destroy({
-        where: { 'metadata.chartInstanceResponseId': chartInstanceResponseId },
-      });
-    });
-
-    res.send({});
-  }),
+  deleteChartInstance(),
 );
 
 encounter.use(encounterRelations);
