@@ -36,7 +36,7 @@ labRequest.get(
   '/:id',
   asyncHandler(async (req, res) => {
     const labRequestRecord = await findRouteObject(req, 'LabRequest');
-    const hasSensitiveTests = labRequestRecord.tests.some((test) => test.labTestType.isSensitive);
+    const hasSensitiveTests = labRequestRecord.tests.some(test => test.labTestType.isSensitive);
     if (hasSensitiveTests) {
       req.checkPermission('read', 'SensitiveLabRequest');
     }
@@ -73,7 +73,7 @@ labRequest.put(
       req.checkPermission('write', 'LabRequestStatus');
     }
 
-    const hasSensitiveTests = labRequestRecord.tests.some((test) => test.labTestType.isSensitive);
+    const hasSensitiveTests = labRequestRecord.tests.some(test => test.labTestType.isSensitive);
     if (hasSensitiveTests) {
       req.checkPermission('write', 'SensitiveLabRequest');
     }
@@ -212,7 +212,7 @@ labRequest.get(
       ),
       makeDeletedAtIsNullFilter('encounter'),
       makeFilter(!canListSensitive, 'sensitive_labs.is_sensitive IS NULL', () => {}),
-    ].filter((f) => f);
+    ].filter(f => f);
 
     const { whereClauses, filterReplacements } = getWhereClausesAndReplacementsFromFilters(
       filters,
@@ -335,7 +335,7 @@ labRequest.get(
       },
     );
 
-    const forResponse = result.map((x) => renameObjectKeys(x.forResponse()));
+    const forResponse = result.map(x => renameObjectKeys(x.forResponse()));
     res.send({
       data: forResponse,
       count,
@@ -356,7 +356,7 @@ labRequest.post(
       throw new NotFoundError();
     }
     req.checkPermission('write', lab);
-    const hasSensitiveTests = lab.tests.some((test) => test.labTestType.isSensitive);
+    const hasSensitiveTests = lab.tests.some(test => test.labTestType.isSensitive);
     if (hasSensitiveTests) {
       req.checkPermission('write', 'SensitiveLabRequest');
     }
@@ -371,13 +371,79 @@ labRelations.get('/:id/notes', notesWithSingleItemListHandler(NOTE_RECORD_TYPES.
 labRelations.get(
   '/:id/tests',
   asyncHandler(async (req, res) => {
+    const { models, params, query } = req;
+    const { LabRequest, LabTestPanelRequest, LabTestType, LabTestPanelLabTestTypes, LabTest } =
+      models;
     const canListSensitive = req.ability.can('list', 'SensitiveLabRequest');
-    const options = canListSensitive
-      ? {}
-      : { additionalFilters: { '$labTestType.is_sensitive$': false } };
-    const response = await getResourceList(req, 'LabTest', 'labRequestId', options);
 
-    res.send(response);
+    // First, get the lab request to check if it's associated with a panel
+    const labRequest = await LabRequest.findByPk(params.id, {
+      include: [
+        {
+          model: LabTestPanelRequest,
+          as: 'labTestPanelRequest',
+        },
+      ],
+    });
+
+    // If this is a panel request, we need to order by the panel's test order
+    if (labRequest?.labTestPanelRequest?.labTestPanelId) {
+      req.checkPermission('list', 'LabTest');
+
+      const { rowsPerPage, page } = query;
+
+      const baseQueryOptions = {
+        where: {
+          labRequestId: params.id,
+          ...(!canListSensitive && { '$labTestType.is_sensitive$': false }),
+        },
+        include: [
+          'category',
+          'labTestMethod',
+          {
+            model: LabTestType,
+            as: 'labTestType',
+            include: [
+              {
+                model: LabTestPanelLabTestTypes,
+                as: 'panelRelations',
+                where: {
+                  labTestPanelId: labRequest.labTestPanelRequest.labTestPanelId,
+                },
+                required: false,
+                attributes: ['order'],
+              },
+            ],
+          },
+        ],
+        order: [
+          [
+            'labTestType',
+            'panelRelations',
+            'order',
+            'ASC',
+          ],
+        ],
+      };
+
+      const { count, rows: objects } = await LabTest.findAndCountAll({
+        ...baseQueryOptions,
+        limit: rowsPerPage,
+        offset: page && rowsPerPage ? page * rowsPerPage : undefined,
+        distinct: true,
+      });
+
+      const data = objects.map(x => x.forResponse());
+
+      res.send({ count, data });
+    } else {
+      // For non-panel requests, use the default ordering
+      const options = canListSensitive
+        ? {}
+        : { additionalFilters: { '$labTestType.is_sensitive$': false } };
+      const response = await getResourceList(req, 'LabTest', 'labRequestId', options);
+      res.send(response);
+    }
   }),
 );
 
@@ -399,7 +465,7 @@ labRelations.put(
     });
 
     // Reject all updates if it includes sensitive tests and user lacks permission
-    const areSensitiveTests = labTests.some((test) => test.labTestType.isSensitive);
+    const areSensitiveTests = labTests.some(test => test.labTestType.isSensitive);
     if (areSensitiveTests) {
       req.checkPermission('write', 'SensitiveLabRequest');
     }
@@ -422,7 +488,7 @@ labRelations.put(
     db.transaction(async () => {
       const promises = [];
 
-      labTests.forEach((labTest) => {
+      labTests.forEach(labTest => {
         req.checkPermission('write', labTest);
         const labTestBody = body[labTest.id];
         const updated = labTest.set(labTestBody);
@@ -547,7 +613,6 @@ labTestPanel.get(
         },
       ],
     });
-
     res.send(response);
   }),
 );
@@ -568,7 +633,7 @@ async function createPanelLabRequests(models, body, note, user) {
   });
 
   const response = await Promise.all(
-    panels.map(async (panel) => {
+    panels.map(async panel => {
       const panelId = panel.id;
       const testPanelRequest = await models.LabTestPanelRequest.create({
         labTestPanelId: panelId,
@@ -577,7 +642,7 @@ async function createPanelLabRequests(models, body, note, user) {
       const innerLabRequestBody = { ...labRequestBody, labTestPanelRequestId: testPanelRequest.id };
 
       const requestSampleDetails = sampleDetails[panelId] || {};
-      const labTestTypeIds = panel.labTestTypes?.map((testType) => testType.id) || [];
+      const labTestTypeIds = panel.labTestTypes?.map(testType => testType.id) || [];
       const labTestCategoryId = panel.categoryId;
       const newLabRequest = await createLabRequest(
         innerLabRequestBody,
@@ -618,7 +683,7 @@ async function createLabRequest(
   const newLabRequest = await models.LabRequest.createWithTests(labRequestData);
   if (note?.content) {
     await newLabRequest.createNote({
-      noteType: NOTE_TYPES.OTHER,
+      noteTypeId: NOTE_TYPES.OTHER,
       date: note.date,
       ...note,
       authorId: user.id,
@@ -657,7 +722,7 @@ async function createIndividualLabRequests(models, body, note, user) {
   const { sampleDetails = {}, ...labRequestBody } = body;
 
   const response = await Promise.all(
-    categories.map(async (category) => {
+    categories.map(async category => {
       const categoryId = category.get('lab_test_category_id');
       const requestSampleDetails = sampleDetails[categoryId] || {};
       const newLabRequest = await createLabRequest(
